@@ -19,6 +19,7 @@ package org.apache.karaf.features.internal.service;
 import java.io.IOException;
 import java.io.InputStream;
 import java.net.URL;
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.EnumSet;
@@ -32,6 +33,7 @@ import java.util.jar.Manifest;
 
 import org.apache.felix.resolver.ResolverImpl;
 import org.apache.felix.utils.version.VersionRange;
+import org.apache.karaf.features.BundleInfo;
 import org.apache.karaf.features.DeploymentEvent;
 import org.apache.karaf.features.Feature;
 import org.apache.karaf.features.FeatureEvent;
@@ -42,6 +44,7 @@ import org.apache.karaf.features.internal.support.TestDownloadManager;
 import org.easymock.EasyMock;
 import org.easymock.IAnswer;
 import org.easymock.IArgumentMatcher;
+import org.easymock.IMocksControl;
 import org.junit.Test;
 import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleException;
@@ -64,35 +67,36 @@ public class DeployerTest {
 
     @Test
     public void testInstallSimpleFeature() throws Exception {
-
+        IMocksControl c = EasyMock.createControl();
         String dataDir = "data1";
 
         TestDownloadManager manager = new TestDownloadManager(getClass(), dataDir);
 
         RepositoryImpl repo = new RepositoryImpl(getClass().getResource(dataDir + "/features.xml").toURI());
-        repo.load(true);
         Feature f100 = repo.getFeatures()[0];
         Feature f101 = repo.getFeatures()[1];
 
-        Deployer.DeployCallback callback = EasyMock.createMock(Deployer.DeployCallback.class);
+        Deployer.DeployCallback callback = c.createMock(Deployer.DeployCallback.class);
         Deployer deployer = new Deployer(manager, resolver, callback);
 
         callback.print(EasyMock.anyString(), EasyMock.anyBoolean());
         EasyMock.expectLastCall().anyTimes();
         callback.callListeners(DeploymentEvent.DEPLOYMENT_STARTED);
         EasyMock.expectLastCall();
-        callback.replaceDigraph(EasyMock.<Map<String, Map<String, Map<String, Set<String>>>>>anyObject(),
-                EasyMock.<Map<String, Set<Long>>>anyObject());
+        callback.replaceDigraph(EasyMock.anyObject(),
+                EasyMock.anyObject());
         EasyMock.expectLastCall();
-        callback.saveState(EasyMock.<State>anyObject());
+        callback.saveState(EasyMock.anyObject());
         EasyMock.expectLastCall();
-        callback.installFeature(f100);
+        callback.installConfigs(f100);
+        EasyMock.expectLastCall();
+        callback.installLibraries(f100);
         EasyMock.expectLastCall();
         callback.callListeners(DeploymentEvent.BUNDLES_INSTALLED);
         EasyMock.expectLastCall();
-        callback.resolveBundles(EasyMock.<Set<Bundle>>anyObject(),
-                                EasyMock.<Map<Resource, List<Wire>>>anyObject(),
-                                EasyMock.<Map<Resource, Bundle>>anyObject());
+        callback.resolveBundles(EasyMock.anyObject(),
+                                EasyMock.anyObject(),
+                                EasyMock.anyObject());
         EasyMock.expectLastCall();
         callback.callListeners(DeploymentEvent.BUNDLES_RESOLVED);
         EasyMock.expectLastCall();
@@ -102,50 +106,47 @@ public class DeployerTest {
         EasyMock.expectLastCall();
 
         Bundle bundleA = createTestBundle(1, Bundle.ACTIVE, dataDir, "a100");
-        EasyMock.expect(callback.installBundle(EasyMock.eq(ROOT_REGION), EasyMock.eq("a100"), EasyMock.<InputStream>anyObject()))
+        EasyMock.expect(callback.installBundle(EasyMock.eq(ROOT_REGION), EasyMock.eq("a100"), EasyMock.anyObject()))
                 .andReturn(bundleA);
 
-        EasyMock.replay(callback);
+        c.replay();
 
         Deployer.DeploymentState dstate = new Deployer.DeploymentState();
         dstate.state = new State();
         dstate.bundles = new HashMap<>();
         dstate.bundlesPerRegion = new HashMap<>();
-        dstate.features = new HashMap<>();
-        dstate.features.put(f100.getId(), f100);
-        dstate.features.put(f101.getId(), f101);
+        dstate.partitionFeatures(Arrays.asList(f100, f101));
         dstate.filtersPerRegion = new HashMap<>();
-        dstate.filtersPerRegion.put(ROOT_REGION, new HashMap<String, Map<String, Set<String>>>());
+        dstate.filtersPerRegion.put(ROOT_REGION, new HashMap<>());
 
         Deployer.DeploymentRequest request = new Deployer.DeploymentRequest();
         request.bundleUpdateRange = DEFAULT_BUNDLE_UPDATE_RANGE;
         request.featureResolutionRange = DEFAULT_FEATURE_RESOLUTION_RANGE;
         request.globalRepository = null;
         request.options = EnumSet.noneOf(Option.class);
-        request.overrides = Collections.emptySet();
         request.stateChanges = Collections.emptyMap();
-        request.updateSnaphots = UPDATE_SNAPSHOTS_NONE;
+        request.updateSnaphots = SnapshotUpdateBehavior.None;
         request.requirements = new HashMap<>();
         addToMapSet(request.requirements, ROOT_REGION, f100.getName() + "/" + new VersionRange(f100.getVersion(), true));
 
         deployer.deploy(dstate, request);
 
-        EasyMock.verify(callback);
+        c.verify();
     }
 
     @Test
     public void testUpdateSimpleFeature() throws Exception {
+        IMocksControl c = EasyMock.createControl();
 
         final String dataDir = "data1";
 
         TestDownloadManager manager = new TestDownloadManager(getClass(), dataDir);
 
         RepositoryImpl repo = new RepositoryImpl(getClass().getResource(dataDir + "/features.xml").toURI());
-        repo.load(true);
         Feature f100 = repo.getFeatures()[0];
         Feature f101 = repo.getFeatures()[1];
 
-        Deployer.DeployCallback callback = EasyMock.createMock(Deployer.DeployCallback.class);
+        Deployer.DeployCallback callback = c.createMock(Deployer.DeployCallback.class);
         Deployer deployer = new Deployer(manager, resolver, callback);
 
         final TestBundle bundleA = createTestBundle(1L, Bundle.ACTIVE, dataDir, "a100");
@@ -156,14 +157,11 @@ public class DeployerTest {
         EasyMock.expectLastCall();
 
         callback.stopBundle(EasyMock.eq(bundleA), anyInt());
-        EasyMock.expectLastCall().andStubAnswer(new IAnswer<Object>() {
-            @Override
-            public Object answer() throws Throwable {
-                bundleA.state = Bundle.RESOLVED;
-                return null;
-            }
+        EasyMock.expectLastCall().andStubAnswer(() -> {
+            bundleA.state = Bundle.RESOLVED;
+            return null;
         });
-        callback.updateBundle(EasyMock.eq(bundleA), EasyMock.<String>anyObject(), EasyMock.<InputStream>anyObject());
+        callback.updateBundle(EasyMock.eq(bundleA), EasyMock.anyObject(), EasyMock.anyObject());
         EasyMock.expectLastCall().andStubAnswer(new IAnswer<Object>() {
             @Override
             public Object answer() throws Throwable {
@@ -180,23 +178,25 @@ public class DeployerTest {
         callback.startBundle(EasyMock.eq(bundleA));
         EasyMock.expectLastCall();
 
-        callback.replaceDigraph(EasyMock.<Map<String, Map<String, Map<String, Set<String>>>>>anyObject(),
-                EasyMock.<Map<String, Set<Long>>>anyObject());
+        callback.replaceDigraph(EasyMock.anyObject(),
+                EasyMock.anyObject());
         EasyMock.expectLastCall();
-        callback.saveState(EasyMock.<State>anyObject());
+        callback.saveState(EasyMock.anyObject());
         EasyMock.expectLastCall();
-        callback.installFeature(f101);
+        callback.installConfigs(f101);
+        EasyMock.expectLastCall();
+        callback.installLibraries(f101);
         EasyMock.expectLastCall();
         callback.callListeners(DeploymentEvent.BUNDLES_INSTALLED);
         EasyMock.expectLastCall();
-        callback.resolveBundles(EasyMock.eq(Collections.<Bundle>singleton(bundleA)),
-                                EasyMock.<Map<Resource, List<Wire>>>anyObject(),
-                                EasyMock.<Map<Resource, Bundle>>anyObject());
+        callback.resolveBundles(EasyMock.eq(Collections.singleton(bundleA)),
+                                EasyMock.anyObject(),
+                                EasyMock.anyObject());
         EasyMock.expectLastCall();
         callback.callListeners(DeploymentEvent.BUNDLES_RESOLVED);
         EasyMock.expectLastCall();
-        callback.refreshPackages(EasyMock.eq(Collections.<Bundle>singleton(bundleA)));
-        EasyMock.expectLastCall();
+        // callback.refreshPackages(EasyMock.eq(Collections.singleton(bundleA)));
+        // EasyMock.expectLastCall();
         callback.callListeners(FeatureEventMatcher.eq(new FeatureEvent(FeatureEvent.EventType.FeatureUninstalled, f100, FeaturesService.ROOT_REGION, false)));
         EasyMock.expectLastCall();
         callback.callListeners(FeatureEventMatcher.eq(new FeatureEvent(FeatureEvent.EventType.FeatureInstalled, f101, FeaturesService.ROOT_REGION, false)));
@@ -204,7 +204,7 @@ public class DeployerTest {
         callback.callListeners(DeploymentEvent.DEPLOYMENT_FINISHED);
         EasyMock.expectLastCall();
 
-        EasyMock.replay(callback);
+        c.replay();
 
         Deployer.DeploymentState dstate = new Deployer.DeploymentState();
         dstate.state = new State();
@@ -214,60 +214,58 @@ public class DeployerTest {
         dstate.bundles.put(1L, bundleA);
         dstate.bundlesPerRegion = new HashMap<>();
         addToMapSet(dstate.bundlesPerRegion, ROOT_REGION, 1L);
-        dstate.features = new HashMap<>();
-        dstate.features.put(f100.getId(), f100);
-        dstate.features.put(f101.getId(), f101);
+        dstate.partitionFeatures(Arrays.asList(f100, f101));
         dstate.filtersPerRegion = new HashMap<>();
-        dstate.filtersPerRegion.put(ROOT_REGION, new HashMap<String, Map<String, Set<String>>>());
+        dstate.filtersPerRegion.put(ROOT_REGION, new HashMap<>());
 
         Deployer.DeploymentRequest request = new Deployer.DeploymentRequest();
         request.bundleUpdateRange = DEFAULT_BUNDLE_UPDATE_RANGE;
         request.featureResolutionRange = DEFAULT_FEATURE_RESOLUTION_RANGE;
         request.globalRepository = null;
         request.options = EnumSet.noneOf(Option.class);
-        request.overrides = Collections.emptySet();
         request.stateChanges = Collections.emptyMap();
-        request.updateSnaphots = UPDATE_SNAPSHOTS_NONE;
+        request.updateSnaphots = SnapshotUpdateBehavior.None;
         request.requirements = new HashMap<>();
         addToMapSet(request.requirements, ROOT_REGION, f101.getName() + "/" + new VersionRange(f101.getVersion(), true));
 
         deployer.deploy(dstate, request);
 
-        EasyMock.verify(callback);
+        c.verify();
     }
 
     @Test
     public void testUpdateServiceBundle() throws Exception {
-
+        IMocksControl c = EasyMock.createControl();
         String dataDir = "data1";
 
         TestDownloadManager manager = new TestDownloadManager(getClass(), dataDir);
 
         RepositoryImpl repo = new RepositoryImpl(getClass().getResource(dataDir + "/features.xml").toURI());
-        repo.load(true);
         Feature f1 = repo.getFeatures()[0];
 
         Bundle serviceBundle = createTestBundle(1, Bundle.ACTIVE, dataDir, "a100");
 
-        Deployer.DeployCallback callback = EasyMock.createMock(Deployer.DeployCallback.class);
+        Deployer.DeployCallback callback = c.createMock(Deployer.DeployCallback.class);
         Deployer deployer = new Deployer(manager, resolver, callback);
 
         callback.print(EasyMock.anyString(), EasyMock.anyBoolean());
         EasyMock.expectLastCall().anyTimes();
         callback.callListeners(DeploymentEvent.DEPLOYMENT_STARTED);
         EasyMock.expectLastCall();
-        callback.replaceDigraph(EasyMock.<Map<String, Map<String, Map<String, Set<String>>>>>anyObject(),
-                EasyMock.<Map<String, Set<Long>>>anyObject());
+        callback.replaceDigraph(EasyMock.anyObject(),
+                EasyMock.anyObject());
         EasyMock.expectLastCall();
-        callback.saveState(EasyMock.<State>anyObject());
+        callback.saveState(EasyMock.anyObject());
         EasyMock.expectLastCall();
         callback.callListeners(DeploymentEvent.BUNDLES_INSTALLED);
         EasyMock.expectLastCall();
-        callback.installFeature(f1);
+        callback.installConfigs(f1);
         EasyMock.expectLastCall();
-        callback.resolveBundles(EasyMock.<Set<Bundle>>anyObject(),
-                                EasyMock.<Map<Resource, List<Wire>>>anyObject(),
-                                EasyMock.<Map<Resource, Bundle>>anyObject());
+        callback.installLibraries(f1);
+        EasyMock.expectLastCall();
+        callback.resolveBundles(EasyMock.anyObject(),
+                                EasyMock.anyObject(),
+                                EasyMock.anyObject());
         EasyMock.expectLastCall();
         callback.callListeners(DeploymentEvent.BUNDLES_RESOLVED);
         EasyMock.expectLastCall();
@@ -276,7 +274,7 @@ public class DeployerTest {
         callback.callListeners(DeploymentEvent.DEPLOYMENT_FINISHED);
         EasyMock.expectLastCall();
 
-        EasyMock.replay(callback);
+        c.replay();
 
         Deployer.DeploymentState dstate = new Deployer.DeploymentState();
         dstate.state = new State();
@@ -284,62 +282,63 @@ public class DeployerTest {
         dstate.bundles.put(serviceBundle.getBundleId(), serviceBundle);
         dstate.bundlesPerRegion = new HashMap<>();
         addToMapSet(dstate.bundlesPerRegion, ROOT_REGION, serviceBundle.getBundleId());
-        dstate.features = Collections.singletonMap(f1.getId(), f1);
+        dstate.partitionFeatures(Collections.singletonList(f1));
         dstate.filtersPerRegion = new HashMap<>();
-        dstate.filtersPerRegion.put(ROOT_REGION, new HashMap<String, Map<String, Set<String>>>());
+        dstate.filtersPerRegion.put(ROOT_REGION, new HashMap<>());
 
         Deployer.DeploymentRequest request = new Deployer.DeploymentRequest();
         request.bundleUpdateRange = DEFAULT_BUNDLE_UPDATE_RANGE;
         request.featureResolutionRange = DEFAULT_FEATURE_RESOLUTION_RANGE;
         request.globalRepository = null;
         request.options = EnumSet.noneOf(Option.class);
-        request.overrides = Collections.emptySet();
         request.stateChanges = Collections.emptyMap();
-        request.updateSnaphots = UPDATE_SNAPSHOTS_NONE;
+        request.updateSnaphots = SnapshotUpdateBehavior.None;
         request.requirements = new HashMap<>();
         addToMapSet(request.requirements, ROOT_REGION, f1.getName());
 
         deployer.deploy(dstate, request);
 
-        EasyMock.verify(callback);
+        c.verify();
     }
 
     @Test
     public void testPrerequisite() throws Exception {
+        IMocksControl c = EasyMock.createControl();
 
         String dataDir = "data2";
 
         TestDownloadManager manager = new TestDownloadManager(getClass(), dataDir);
 
         RepositoryImpl repo = new RepositoryImpl(getClass().getResource(dataDir + "/features.xml").toURI());
-        repo.load(true);
         Feature f1 = repo.getFeatures()[0];
         Feature f2 = repo.getFeatures()[1];
 
         Bundle serviceBundle1 = createTestBundle(1, Bundle.ACTIVE, dataDir, "a100");
         Bundle serviceBundle2 = createTestBundle(2, Bundle.ACTIVE, dataDir, "b100");
 
-        Deployer.DeployCallback callback = EasyMock.createMock(Deployer.DeployCallback.class);
+        Deployer.DeployCallback callback = c.createMock(Deployer.DeployCallback.class);
         Deployer deployer = new Deployer(manager, resolver, callback);
 
         callback.print(EasyMock.anyString(), EasyMock.anyBoolean());
         EasyMock.expectLastCall().anyTimes();
         callback.callListeners(DeploymentEvent.DEPLOYMENT_STARTED);
         EasyMock.expectLastCall();
-        callback.installBundle(EasyMock.eq(ROOT_REGION), EasyMock.eq("a100"), EasyMock.<InputStream>anyObject());
+        callback.installBundle(EasyMock.eq(ROOT_REGION), EasyMock.eq("a100"), EasyMock.anyObject());
         EasyMock.expectLastCall().andReturn(serviceBundle1);
-        callback.replaceDigraph(EasyMock.<Map<String, Map<String, Map<String, Set<String>>>>>anyObject(),
-                EasyMock.<Map<String, Set<Long>>>anyObject());
+        callback.replaceDigraph(EasyMock.anyObject(),
+                EasyMock.anyObject());
         EasyMock.expectLastCall();
-        callback.saveState(EasyMock.<State>anyObject());
+        callback.saveState(EasyMock.anyObject());
         EasyMock.expectLastCall();
-        callback.installFeature(f1);
+        callback.installConfigs(EasyMock.anyObject());
+        EasyMock.expectLastCall();
+        callback.installLibraries(EasyMock.anyObject());
         EasyMock.expectLastCall();
         callback.callListeners(DeploymentEvent.BUNDLES_INSTALLED);
         EasyMock.expectLastCall();
-        callback.resolveBundles(EasyMock.<Set<Bundle>>anyObject(),
-                EasyMock.<Map<Resource, List<Wire>>>anyObject(),
-                EasyMock.<Map<Resource, Bundle>>anyObject());
+        callback.resolveBundles(EasyMock.anyObject(),
+                EasyMock.anyObject(),
+                EasyMock.anyObject());
         EasyMock.expectLastCall();
         callback.callListeners(DeploymentEvent.BUNDLES_RESOLVED);
         EasyMock.expectLastCall();
@@ -348,26 +347,23 @@ public class DeployerTest {
         callback.callListeners(DeploymentEvent.DEPLOYMENT_FINISHED);
         EasyMock.expectLastCall();
 
-        EasyMock.replay(callback);
+        c.replay();
 
         Deployer.DeploymentState dstate = new Deployer.DeploymentState();
         dstate.state = new State();
         dstate.bundles = new HashMap<>();
         dstate.bundlesPerRegion = new HashMap<>();
-        dstate.features = new HashMap<>();
-        dstate.features.put(f1.getId(), f1);
-        dstate.features.put(f2.getId(), f2);
+        dstate.partitionFeatures(Arrays.asList(f1, f2));
         dstate.filtersPerRegion = new HashMap<>();
-        dstate.filtersPerRegion.put(ROOT_REGION, new HashMap<String, Map<String, Set<String>>>());
+        dstate.filtersPerRegion.put(ROOT_REGION, new HashMap<>());
 
         Deployer.DeploymentRequest request = new Deployer.DeploymentRequest();
         request.bundleUpdateRange = DEFAULT_BUNDLE_UPDATE_RANGE;
         request.featureResolutionRange = DEFAULT_FEATURE_RESOLUTION_RANGE;
         request.globalRepository = null;
         request.options = EnumSet.noneOf(Option.class);
-        request.overrides = Collections.emptySet();
         request.stateChanges = Collections.emptyMap();
-        request.updateSnaphots = UPDATE_SNAPSHOTS_NONE;
+        request.updateSnaphots = SnapshotUpdateBehavior.None;
         request.requirements = new HashMap<>();
         addToMapSet(request.requirements, ROOT_REGION, f2.getName());
 
@@ -378,28 +374,30 @@ public class DeployerTest {
             // ok
         }
 
-        EasyMock.verify(callback);
+        c.verify();
 
-        EasyMock.reset(callback);
+        c.reset();
 
         callback.print(EasyMock.anyString(), EasyMock.anyBoolean());
         EasyMock.expectLastCall().anyTimes();
         callback.callListeners(DeploymentEvent.DEPLOYMENT_STARTED);
         EasyMock.expectLastCall();
-        callback.installBundle(EasyMock.eq(ROOT_REGION), EasyMock.eq("b100"), EasyMock.<InputStream>anyObject());
+        callback.installBundle(EasyMock.eq(ROOT_REGION), EasyMock.eq("b100"), EasyMock.anyObject());
         EasyMock.expectLastCall().andReturn(serviceBundle2);
-        callback.replaceDigraph(EasyMock.<Map<String, Map<String, Map<String, Set<String>>>>>anyObject(),
-                EasyMock.<Map<String, Set<Long>>>anyObject());
+        callback.replaceDigraph(EasyMock.anyObject(),
+                EasyMock.anyObject());
         EasyMock.expectLastCall();
-        callback.saveState(EasyMock.<State>anyObject());
+        callback.saveState(EasyMock.anyObject());
         EasyMock.expectLastCall();
-        callback.installFeature(f2);
+        callback.installConfigs(f2);
+        EasyMock.expectLastCall();
+        callback.installLibraries(f2);
         EasyMock.expectLastCall();
         callback.callListeners(DeploymentEvent.BUNDLES_INSTALLED);
         EasyMock.expectLastCall();
-        callback.resolveBundles(EasyMock.<Set<Bundle>>anyObject(),
-                EasyMock.<Map<Resource, List<Wire>>>anyObject(),
-                EasyMock.<Map<Resource, Bundle>>anyObject());
+        callback.resolveBundles(EasyMock.anyObject(),
+                EasyMock.anyObject(),
+                EasyMock.anyObject());
         EasyMock.expectLastCall();
         callback.callListeners(DeploymentEvent.BUNDLES_RESOLVED);
         EasyMock.expectLastCall();
@@ -419,20 +417,17 @@ public class DeployerTest {
         dstate.bundles.put(serviceBundle1.getBundleId(), serviceBundle1);
         dstate.bundlesPerRegion = new HashMap<>();
         addToMapSet(dstate.bundlesPerRegion, ROOT_REGION, serviceBundle1.getBundleId());
-        dstate.features = new HashMap<>();
-        dstate.features.put(f1.getId(), f1);
-        dstate.features.put(f2.getId(), f2);
+        dstate.partitionFeatures(Arrays.asList(f1, f2));
         dstate.filtersPerRegion = new HashMap<>();
-        dstate.filtersPerRegion.put(ROOT_REGION, new HashMap<String, Map<String, Set<String>>>());
+        dstate.filtersPerRegion.put(ROOT_REGION, new HashMap<>());
 
         request = new Deployer.DeploymentRequest();
         request.bundleUpdateRange = DEFAULT_BUNDLE_UPDATE_RANGE;
         request.featureResolutionRange = DEFAULT_FEATURE_RESOLUTION_RANGE;
         request.globalRepository = null;
         request.options = EnumSet.noneOf(Option.class);
-        request.overrides = Collections.emptySet();
         request.stateChanges = Collections.emptyMap();
-        request.updateSnaphots = UPDATE_SNAPSHOTS_NONE;
+        request.updateSnaphots = SnapshotUpdateBehavior.None;
         request.requirements = new HashMap<>();
         addToMapSet(request.requirements, ROOT_REGION, f2.getName());
 
@@ -462,12 +457,13 @@ public class DeployerTest {
     }
 
     private void doTestPrereqOnPrereq(int scenario) throws Exception {
+        IMocksControl c = EasyMock.createControl();
+
         String dataDir = "data3";
 
         TestDownloadManager manager = new TestDownloadManager(getClass(), dataDir);
 
         RepositoryImpl repo = new RepositoryImpl(getClass().getResource(dataDir + "/features.xml").toURI());
-        repo.load(true);
 
         Map<String, Bundle> bundles = new HashMap<>();
         bundles.put("a100", createTestBundle(1, Bundle.ACTIVE, dataDir, "a100"));
@@ -478,10 +474,7 @@ public class DeployerTest {
         dstate.state = new State();
         dstate.bundles = new HashMap<>();
         dstate.bundlesPerRegion = new HashMap<>();
-        dstate.features = new HashMap<>();
-        for (Feature f : repo.getFeatures()) {
-            dstate.features.put(f.getId(), f);
-        }
+        dstate.partitionFeatures(Arrays.asList(repo.getFeatures()));
         dstate.filtersPerRegion = new HashMap<>();
         dstate.filtersPerRegion.put(ROOT_REGION, new HashMap<>());
 
@@ -490,12 +483,12 @@ public class DeployerTest {
         request.featureResolutionRange = DEFAULT_FEATURE_RESOLUTION_RANGE;
         request.globalRepository = null;
         request.options = EnumSet.noneOf(Option.class);
-        request.overrides = Collections.emptySet();
         request.stateChanges = Collections.emptyMap();
-        request.updateSnaphots = UPDATE_SNAPSHOTS_NONE;
+        request.updateSnaphots = SnapshotUpdateBehavior.None;
 
         MyDeployCallback callback = new MyDeployCallback(dstate, bundles);
         Deployer deployer = new Deployer(manager, resolver, callback);
+        c.replay();
 
         for (int i = 1; i <= 4; i++) {
             request.requirements = new HashMap<>();
@@ -577,10 +570,6 @@ public class DeployerTest {
         public void persistResolveRequest(Deployer.DeploymentRequest request) throws IOException {
         }
 
-        @Override
-        public void installFeature(Feature feature) throws IOException, InvalidSyntaxException {
-        }
-
         @Override
         public void callListeners(FeatureEvent featureEvent) {
         }
@@ -596,34 +585,62 @@ public class DeployerTest {
 
         @Override
         public void updateBundle(Bundle bundle, String uri, InputStream is) throws BundleException {
+
         }
 
         @Override
         public void uninstall(Bundle bundle) throws BundleException {
+
         }
 
         @Override
         public void startBundle(Bundle bundle) throws BundleException {
+
         }
 
         @Override
         public void stopBundle(Bundle bundle, int options) throws BundleException {
+
         }
 
         @Override
         public void setBundleStartLevel(Bundle bundle, int startLevel) {
-        }
 
-        @Override
-        public void refreshPackages(Collection<Bundle> bundles) throws InterruptedException {
         }
 
         @Override
         public void resolveBundles(Set<Bundle> bundles, Map<Resource, List<Wire>> wiring, Map<Resource, Bundle> resToBnd) {
+
+        }
+
+        @Override
+        public void refreshPackages(Collection<Bundle> bundles) throws InterruptedException {
+
         }
 
         @Override
         public void replaceDigraph(Map<String, Map<String, Map<String, Set<String>>>> policies, Map<String, Set<Long>> bundles) throws BundleException, InvalidSyntaxException {
+
+        }
+
+        @Override
+        public void installConfigs(Feature feature) throws IOException, InvalidSyntaxException {
+
+        }
+
+        @Override
+        public void deleteConfigs(Feature feature) throws IOException, InvalidSyntaxException {
+
+        }
+
+        @Override
+        public void installLibraries(Feature feature) throws IOException {
+
+        }
+
+        @Override
+        public void bundleBlacklisted(BundleInfo bundleInfo) {
+
         }
     }
 }
